@@ -32,7 +32,7 @@ test_that("deletion statistics computed correctly with na.exclude", {
   expect_true(all(is.na(residuals(m.miss)[c(1, 4, 10)])))
   expect_true(all(is.na(fitted(m.miss)[c(1, 4, 10)])))
   expect_true(all(is.na(rstudent(m.miss)[c(1, 4, 10)])))
-  expect_true(all(is.na(dffits(m.miss)[c(1, 4, 10)])))
+  expect_true(all(is.na(influence(m.miss)$dffits[c(1, 4, 10)])))
   expect_true(all(is.na(cooks.distance(m.miss)[c(1, 4, 10)])))
   expect_true(all(is.na(dfbeta(m.miss)[c(1, 4, 10), ])))
 })
@@ -44,7 +44,7 @@ test_that("rownames of deletion statistics preserved with na.omit", {
   expect_equal(names(residuals(m.miss.2)), nms)
   expect_equal(names(fitted(m.miss.2)), nms)
   expect_equal(names(rstudent(m.miss.2)), nms)
-  expect_equal(names(dffits(m.miss.2)), nms)
+  expect_equal(names(influence(m.miss.2)$dffits), nms)
   expect_equal(names(cooks.distance(m.miss.2)), nms)
   expect_equal(rownames(dfbeta(m.miss.2)), nms)
 })
